@@ -1038,7 +1038,7 @@ static int resync(m2xxh_t* m2xxh)
   int i;
   int timeout = m2xxh->io->timeout;
   m2xxh->io->timeout = 100;
-  for(i = 0; !ok && i < ISO7816_HEADER_SIZE; i++) {
+  for(i = 0; !ok && i < ISO7816_HEADER_SIZE * 2; i++) {
     if(m2xxh->verbose > 1)
       fprintf(stderr, "M2XXH send null byte\n");
     if(write(m2xxh->io->fd, &nul, 1) != 1) {
@@ -1048,7 +1048,8 @@ static int resync(m2xxh_t* m2xxh)
       return -1;
     }
     status_check(m2xxh, 0 /* nop */, 0 /* nop */);
-    if(m2xxh->error == RFID_ERROR_TRY_AGAIN) {
+    if(m2xxh->error == RFID_ERROR_TRY_AGAIN ||
+       m2xxh->error == RFID_ERROR_UNKNOWN_ERROR) {
       if(m2xxh->verbose > 1)
 	fprintf(stderr, "M2XXH timeout\n");
       /* Timeout, just try again. */
@@ -1333,7 +1334,7 @@ static int drv_iso15693_command(struct rfid_reader* reader, u_int8_t* data, int
      * Collision : CRC error.
      * Send a EOF : send a TRANSMIT with no data (0x80,0xC2,0x73,0x0A,0x00)
      */
-    param |= M2XXH_TRANSMIT_TIMEOUT_00; /* Assume it's blasting fast. */
+    param |= M2XXH_TRANSMIT_TIMEOUT_10; /* Assume it's blasting fast. */
 
     {
       int slot = 0;
